"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.articleController = void 0;
const addNewArticle_1 = require("../db/article/addNewArticle");
const getAllArticle_1 = require("../db/article/getAllArticle");
const getArticleByCriteria_1 = require("../db/article/getArticleByCriteria");
const updateArticle_1 = require("../db/article/updateArticle");
const deleteArticle_1 = require("../db/article/deleteArticle");
const CustomError_1 = require("../error/CustomError");
class articleController {
    getAllArticle() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            let result;
            try {
                result = yield (0, getAllArticle_1.getAllArticle)();
            }
            catch (error) {
                next(error);
                return;
            }
            res.status(200).json(result);
        });
    }
    getProductByCriteria() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            let value = req.params.selector == "id"
                ? Number(req.params.value)
                : req.params.value;
            let result;
            try {
                result = yield (0, getArticleByCriteria_1.getArticleByCriteria)(req.params.selector, value);
            }
            catch (error) {
                next(error);
                return;
            }
            res.json(result);
        });
    }
    addArticle() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            const { name, preis, beschreibung, categoryId } = req.body;
            let id;
            try {
                id = yield (0, addNewArticle_1.addNewArticle)(preis, beschreibung, name, categoryId);
            }
            catch (error) {
                next(error);
                return;
            }
            res.status(201).json({
                message: "article added",
                id: id,
                name: name,
            });
        });
    }
    updateArticle() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            let articleObj = req.body;
            let isUpdated;
            try {
                isUpdated = yield (0, updateArticle_1.updateArticle)(req.body.id, articleObj);
            }
            catch (error) {
                next(error);
                return;
            }
            isUpdated
                ? res.status(204).json({ message: "article updated successfully" })
                : res.status(500);
        });
    }
    deleteArticle() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            const id = Number(req.query.id);
            try {
                yield (0, deleteArticle_1.deleteArticle)(id);
            }
            catch (error) {
                next(error);
                return;
            }
            res.status(204).send();
        });
    }
    searchProductIngoogle() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            const productName = req.query.productName;
            console.log(productName);
            const key = "AIzaSyC4mtQ7jXavedm9KUrBP9n9HVquNobCzrU";
            try {
                const response = yield fetch(`https://www.googleapis.com/customsearch/v1?key=${key}&cx=a143f4f509e5e4990&q=${productName}`);
                if (!response.ok) {
                    throw new CustomError_1.CustomError(yield response.json(), response.status, "UNKNOWN", "Data can't be fetched from external api");
                }
                const body = yield response.json();
                res.json(body);
            }
            catch (error) {
                next(new CustomError_1.CustomError("fetching data Failed ", 404, "UNKNOWN", "Data can't be fetched from external api"));
            }
        });
    }
}
exports.articleController = articleController;
