"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShoppingCartController = void 0;
const getAllShoppingCarts_1 = require("../db/shoppingCart/getAllShoppingCarts");
const createShoppingCart_1 = require("../db/shoppingCart/createShoppingCart");
const getShoppingCartByCriteria_1 = require("../db/shoppingCart/getShoppingCartByCriteria");
const deleteShoppingCart_1 = require("../db/shoppingCart/deleteShoppingCart");
const updateShoppingCart_1 = require("../db/shoppingCart/updateShoppingCart");
const getShoppingListContainingItem_1 = require("../db/shoppingCart/getShoppingListContainingItem");
class ShoppingCartController {
    createShoppingCart() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            let body = req.body;
            let id;
            try {
                id = yield (0, createShoppingCart_1.createShoppingCart)(body);
            }
            catch (error) {
                next(error);
                return;
            }
            res.status(201).json({
                message: "shopping cart created ",
                id: id,
            });
        });
    }
    getAllShoppingCart() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            let result;
            try {
                result = yield (0, getAllShoppingCarts_1.getAllShoppingCarts)();
            }
            catch (error) {
                next(error);
                return;
            }
            res.status(200).json(result);
        });
    }
    getShoppingCarteByCriteria() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            let value = req.params.selector == "id"
                ? Number(req.params.value)
                : req.params.value;
            let result;
            try {
                result = yield (0, getShoppingCartByCriteria_1.getShoppingCarteByCriteria)(req.params.selector, value);
            }
            catch (error) {
                next(error);
                return;
            }
            res.json(result);
        });
    }
    getShoppingListContainingItemById() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            const id = req.query.id;
            console.log(id);
            try {
                const response = yield (0, getShoppingListContainingItem_1.getShoppingListContainingItemById)(Number(id));
                res.json(response);
            }
            catch (error) {
                next(error);
            }
        });
    }
    getShoppingListContainingItemByName() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            const name = req.query.name;
            try {
                const response = yield (0, getShoppingListContainingItem_1.getShoppingListContainingItemByName)(String(name));
                res.json(response);
            }
            catch (error) {
                next(error);
            }
        });
    }
    deleteShoppingCart() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            const id = Number(req.query.id);
            try {
                yield (0, deleteShoppingCart_1.deleteShoppingCart)(id);
            }
            catch (error) {
                next(error);
                return;
            }
            res.status(204).send();
        });
    }
    updateShoppingCart() {
        return (req, res, next) => __awaiter(this, void 0, void 0, function* () {
            const { id, name, beschreibung } = req.body;
            const body = {
                name: name,
                beschreibung: beschreibung,
            };
            try {
                yield (0, updateShoppingCart_1.updateShoppingCart)(id, body);
            }
            catch (error) {
                next(error);
                return;
            }
            res.status(204).json({ message: "Shopping cart updated successfully" });
        });
    }
}
exports.ShoppingCartController = ShoppingCartController;
