"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteItemFromShoppingCart = void 0;
const CustomError_1 = require("../../error/CustomError");
const connect_1 = require("../connect");
const deleteItemFromShoppingCart = (itemId, cartId) => __awaiter(void 0, void 0, void 0, function* () {
    const db = new connect_1.DB();
    const client = db.Client;
    try {
        const deleteQuery = `
      DELETE FROM mengeRealtation
      WHERE articleId = $1 AND einkauflisteId = $2
      RETURNING id
    `;
        const deleteValues = [itemId, cartId];
        const deleteResult = yield client.query(deleteQuery, deleteValues);
        if (deleteResult.rowCount === 0) {
            throw new CustomError_1.CustomError("Item Not in Cart", 404, "ITEM_NOT_IN_CART", `The item with ID ${itemId} is not in the shopping cart with ID ${cartId}.`);
        }
        return { message: "Item deleted successfully", id: deleteResult.rows[0].id };
    }
    catch (err) {
        throw err;
    }
    finally {
        db.destroy();
    }
});
exports.deleteItemFromShoppingCart = deleteItemFromShoppingCart;
