"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getItemsInOrder = void 0;
const connect_1 = require("../connect");
const CustomError_1 = require("../../error/CustomError");
const getItemsInOrder = (cartId) => __awaiter(void 0, void 0, void 0, function* () {
    let db = new connect_1.DB();
    let client = db.Client;
    let cartInfoQuery = `
    SELECT name AS cartName, beschreibung AS cartBeschreibung, erstellungsdatum AS erstellungsDatum
    FROM einkaufliste
    WHERE id = $1
  `;
    let cartInfo = yield client
        .query(cartInfoQuery, [cartId])
        .then((res) => {
        if (res.rowCount === 0) {
            throw new CustomError_1.CustomError("The cart ID does not exist", 404, "ID_NOT_EXISTING", "No existing cart ID");
        }
        return res.rows[0];
    })
        .catch((err) => {
        throw err;
    });
    let query = `
    SELECT a.id AS articleId , m.menge AS quantity, a.name AS articleName, a.preis AS articlePreis, a.beschreibung AS articleBeschreibung
    FROM mengeRealtation m
    JOIN article a ON a.id = m.articleId
    WHERE m.einkauflisteId = $1
  `;
    let values = [cartId];
    let articles = [];
    yield client
        .query(query, values)
        .then((res) => {
        articles = res.rows;
    })
        .catch((err) => {
        throw err;
    })
        .finally(() => {
        db.destroy();
    });
    let response = {
        cartId: cartId,
        name: cartInfo.cartname,
        beschreibung: cartInfo.cartbeschreibung,
        erstellungsdatum: cartInfo.erstellungsdatum,
        items: articles.map((item) => ({
            id: item.articleid,
            name: item.articlename,
            preis: Number(item.articlepreis),
            beshreibung: item.articlebeschreibung,
            quantity: item.quantity,
        })),
    };
    return response;
});
exports.getItemsInOrder = getItemsInOrder;
