"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addProductSchema = exports.addProductChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
const zod_1 = require("zod");
class addProductChecker extends checkerInterface_1.Checker {
    constructor(body, isUpdate) {
        super();
        this.body = isUpdate
            ? { id: 1, preis: 3, beschreibung: "mock data ", name: "mock data" }
            : {
                preis: 3,
                beschreibung: "mock data ",
                name: "mock data",
                categoryId: 1,
            };
        this.newBody = body;
    }
    check() {
        const keysA = Object.keys(this.body);
        const keysB = Object.keys(this.newBody);
        if (keysA.length != keysB.length) {
            throw new CustomError_1.CustomError("Es fehlen ein paar Keys", 422, "Unprocessable Entity", "Details: Erwartete Keys sind " +
                keysA.join(", ") +
                ", aber erhalten wurden " +
                keysB.join(", "));
        }
        const checkSameKeys = keysA.every((key) => {
            return keysB.includes(key);
        });
        if (!checkSameKeys) {
            throw new CustomError_1.CustomError("Es fehlen bestimmte Keys oder es gibt unpassende Keys", 400, "CODE_STRING", "Details: Erwartete Keys sind " +
                keysA.join(", ") +
                ", aber erhalten wurden " +
                keysB.join(", "));
        }
        let values = Object.values(this.newBody);
        let checkValidValues = values.every((item) => {
            console.log(item);
            return (item !== null &&
                item !== undefined &&
                !(typeof item === "string" && item.length === 0));
        });
        if (!checkValidValues) {
            throw new CustomError_1.CustomError("Ungültige Werte vorhanden", 400, "CODE_STRING", "Details: Einige Werte sind null oder undefined");
        }
        if (this.newBody.categoryId <= 0) {
            throw new CustomError_1.CustomError("categoryId is undefined or smaller or equal to 0", 412, "CODE_STRING", "Details: categoryId is undefined or smaller or equal to 0");
        }
        return true;
    }
}
exports.addProductChecker = addProductChecker;
exports.addProductSchema = zod_1.z.object({
    preis: zod_1.z
        .number()
        .min(0, { message: "Price must be greater than or equal to 0." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid price", 422, "PRICE_ERROR", err.error.message);
    }),
    beschreibung: zod_1.z
        .string()
        .min(1, { message: "Description must be a non-empty string." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid description", 422, "DESCRIPTION_ERROR", err.error.message);
    }),
    name: zod_1.z
        .string()
        .min(1, { message: "Name must be a non-empty string." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid name", 422, "NAME_ERROR", err.error.message);
    }),
    id: zod_1.z.number().optional(),
    categoryId: zod_1.z
        .number()
        .min(1, { message: "CategoryId must be greater than 0." })
        .optional()
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid categoryId", 422, "CATEGORY_ERROR", err.error.message);
    }),
});
