"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteArticleSchema = exports.DeleteArticleChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
class DeleteArticleChecker extends checkerInterface_1.Checker {
    constructor(queryParams) {
        super();
        this.queryParams = queryParams;
    }
    check() {
        if (!this.queryParams.hasOwnProperty("id")) {
            throw new CustomError_1.CustomError("Missing 'id' Parameter", 400, "MISSING_ID", "The 'id' parameter is required to delete an article, but it was not provided in the query.");
        }
        if (typeof Number(this.queryParams['id']) !== 'number') {
            throw new CustomError_1.CustomError("Invalid 'id' Parameter Type", 400, "INVALID_ID_TYPE", `The 'id' parameter must be a number. Received type: ${typeof this.queryParams['id']}.`);
        }
        if (Object.keys(this.queryParams).length !== 1) {
            throw new CustomError_1.CustomError("Unexpected Query Parameters", 400, "UNEXPECTED_QUERY_PARAMS", `Only the 'id' parameter is allowed, but received: ${Object.keys(this.queryParams).join(', ')}.`);
        }
        return true;
    }
}
exports.DeleteArticleChecker = DeleteArticleChecker;
const zod_1 = require("zod");
exports.deleteArticleSchema = zod_1.z.object({
    id: zod_1.z
        .string()
        .regex(/^\d+$/, { message: "The 'id' parameter must be a valid number." })
        .transform((val) => Number(val)) // Transformiert die ID in eine Zahl
        .refine((val) => !isNaN(val), {
        message: "The 'id' parameter must be a number.",
    })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid 'id' Parameter", 400, "INVALID_ID", err.error.message);
    }),
});
