"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateProductSchema = exports.UpdateProductChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
const addProductChecker_1 = require("./addProductChecker");
const zod_1 = require("zod");
class UpdateProductChecker extends checkerInterface_1.Checker {
    constructor(body) {
        super();
        this.body = { preis: 3, beschreibung: "mock data ", name: "mock data" };
        this.newBody = body;
    }
    check() {
        let useChecker = new addProductChecker_1.addProductChecker(this.newBody, true);
        useChecker.check();
        if (!this.newBody.hasOwnProperty("id")) {
            throw new CustomError_1.CustomError("no Id Property", 400, "NO_ID_PROPERTY", "The 'id' property is missing.");
        }
        if (typeof this.newBody['id'] !== 'number') {
            let type = typeof this.newBody['id'];
            throw new CustomError_1.CustomError("id is not a number ", 400, "ID_NOT_NUMBER", `The 'id' property should be a number, but it is a ${type}.`);
        }
        return true;
    }
}
exports.UpdateProductChecker = UpdateProductChecker;
exports.updateProductSchema = zod_1.z.object({
    preis: zod_1.z
        .number()
        .min(0, { message: "Price must be greater than or equal to 0." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid price", 422, "PRICE_ERROR", err.error.message);
    }),
    beschreibung: zod_1.z
        .string()
        .min(1, { message: "Description must be a non-empty string." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid description", 422, "DESCRIPTION_ERROR", err.error.message);
    }),
    name: zod_1.z
        .string()
        .min(1, { message: "Name must be a non-empty string." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid name", 422, "NAME_ERROR", err.error.message);
    }),
    id: zod_1.z
        .number()
        .min(1, { message: "ID must be greater than 0." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid id", 422, "ID_ERROR", err.error.message);
    }),
});
