"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteItemSchema = exports.updateProductQuantitySchema = exports.getItemsSchema = exports.addItemSchema = exports.DeleteItemFromCartChecker = exports.UpdateProductMengeChecker = exports.GetItemsInCartChecker = exports.AddNewItemToOrderChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
class AddNewItemToOrderChecker {
    constructor(body) {
        this.body = body;
    }
    check() {
        const { itemId, cartId, quantity } = this.body;
        if (itemId === undefined ||
            cartId === undefined ||
            quantity === undefined) {
            throw new CustomError_1.CustomError("Fehlende Felder", 400, "MISSING_FIELDS", "Details: 'itemId', 'cartId' und 'quantity' sind erforderlich.");
        }
        if (typeof itemId !== "number") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "itemId"', 400, "INVALID_ITEM_ID", 'Details: Der Wert für "itemId" muss eine Zahl sein.');
        }
        if (typeof quantity !== "number") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "quantity"', 400, "INVALID_QUANTITY", 'Details: Der Wert für "quantity" muss eine Zahl sein.');
        }
        if (typeof cartId !== "number") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "cartId"', 400, "INVALID_CART_ID", 'Details: Der Wert für "cartId" muss eine Zahl sein.');
        }
        return true;
    }
}
exports.AddNewItemToOrderChecker = AddNewItemToOrderChecker;
class GetItemsInCartChecker {
    constructor(query) {
        this.query = query;
    }
    check() {
        const { cartId } = this.query;
        if (cartId === undefined) {
            throw new CustomError_1.CustomError('Fehlendes Feld "cartId"', 400, "MISSING_CART_ID", 'Details: "cartId" ist erforderlich.');
        }
        if (typeof Number(cartId) !== "number") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "cartId"', 400, "INVALID_CART_ID", 'Details: Der Wert für "cartId" muss eine Zahl sein.');
        }
        return true;
    }
}
exports.GetItemsInCartChecker = GetItemsInCartChecker;
class UpdateProductMengeChecker {
    constructor(body) {
        this.body = body;
    }
    check() {
        const { cartId, articleId, newQuantity } = this.body;
        if (cartId === undefined ||
            articleId === undefined ||
            newQuantity === undefined) {
            throw new CustomError_1.CustomError("Fehlende Felder", 400, "MISSING_FIELDS", "Details: 'cartId', 'articleId' und 'newQuantity' sind erforderlich.");
        }
        if (typeof cartId !== "number") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "cartId"', 400, "INVALID_CART_ID", 'Details: Der Wert für "cartId" muss eine Zahl sein.');
        }
        if (typeof articleId !== "number") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "articleId"', 400, "INVALID_ARTICLE_ID", 'Details: Der Wert für "articleId" muss eine Zahl sein.');
        }
        if (typeof newQuantity !== "number") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "newQuantity"', 400, "INVALID_QUANTITY", 'Details: Der Wert für "newQuantity" muss eine Zahl sein.');
        }
        return true;
    }
}
exports.UpdateProductMengeChecker = UpdateProductMengeChecker;
class DeleteItemFromCartChecker {
    constructor(query) {
        this.query = query;
    }
    check() {
        const { itemId, cartId } = this.query;
        if (itemId === undefined || cartId === undefined) {
            throw new CustomError_1.CustomError("Missing Fields", 400, "MISSING_FIELDS", "Details: 'itemId' and 'cartId' are required.");
        }
        if (typeof itemId !== "number") {
            throw new CustomError_1.CustomError('Invalid "itemId" Value', 400, "INVALID_ITEM_ID", 'Details: "itemId" must be a number.');
        }
        if (typeof cartId !== "number") {
            throw new CustomError_1.CustomError('Invalid "cartId" Value', 400, "INVALID_CART_ID", 'Details: "cartId" must be a number.');
        }
        return true;
    }
}
exports.DeleteItemFromCartChecker = DeleteItemFromCartChecker;
const zod_1 = require("zod");
exports.addItemSchema = zod_1.z.object({
    itemId: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "itemId must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid itemId", 400, "INVALID_ITEM_ID", err.error.message);
    }),
    cartId: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "cartId must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid cartId", 400, "INVALID_CART_ID", err.error.message);
    }),
    quantity: zod_1.z
        .number()
        .int()
        .positive({ message: "quantity must be a positive integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid quantity", 400, "INVALID_QUANTITY", err.error.message);
    }),
});
exports.getItemsSchema = zod_1.z.object({
    cartId: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "cartId must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid cartId", 400, "INVALID_CART_ID", err.error.message);
    }),
});
exports.updateProductQuantitySchema = zod_1.z.object({
    cartId: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "cartId must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid cartId", 400, "INVALID_CART_ID", err.error.message);
    }),
    articleId: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "articleId must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid articleId", 400, "INVALID_ARTICLE_ID", err.error.message);
    }),
    newQuantity: zod_1.z
        .number()
        .int()
        .positive({ message: "newQuantity must be a positive integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid newQuantity", 400, "INVALID_QUANTITY", err.error.message);
    }),
});
exports.deleteItemSchema = zod_1.z.object({
    itemId: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "itemId must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid itemId", 400, "INVALID_ITEM_ID", err.error.message);
    }),
    cartId: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "cartId must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid cartId", 400, "INVALID_CART_ID", err.error.message);
    }),
});
