"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.deleteShoppingCartSchema = exports.DeleteShoppingCartChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
class DeleteShoppingCartChecker extends checkerInterface_1.Checker {
    constructor(body) {
        super();
        this.body = body;
    }
    check() {
        if (!this.body.hasOwnProperty("id") || typeof this.body.id !== "number" || isNaN(this.body.id)) {
            throw new CustomError_1.CustomError('Ungültige oder fehlende ID', 400, "INVALID_OR_MISSING_ID", "Details: Die 'id' muss eine gültige Zahl sein und im Anfragekörper vorhanden sein.");
        }
        const keys = Object.keys(this.body);
        if (keys.length > 1) {
            throw new CustomError_1.CustomError('Unerwartete Felder für das Löschen', 400, "UNEXPECTED_FIELDS_FOR_DELETE", "Details: Nur die 'id' sollte für eine Löschanfrage vorhanden sein.");
        }
        return true;
    }
}
exports.DeleteShoppingCartChecker = DeleteShoppingCartChecker;
const zod_1 = require("zod");
exports.deleteShoppingCartSchema = zod_1.z.object({
    id: zod_1.z
        .number()
        .min(1, { message: "The 'id' field must be a valid number and greater than 0." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid or missing 'id'", 400, "INVALID_OR_MISSING_ID", err.error.message);
    }),
});
