"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.queryNameSchema = exports.queryIdSchema = exports.QueryNameChecker = exports.QueryIdChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
class QueryIdChecker extends checkerInterface_1.Checker {
    constructor(query) {
        super();
        this.query = query;
    }
    check() {
        console.log(this.query.id);
        if (!this.query.hasOwnProperty("id") ||
            typeof Number(this.query.id) !== "number") {
            throw new CustomError_1.CustomError("Invalid or missing ID", 400, "INVALID_OR_MISSING_ID", "Details: The 'id' must be a valid number and present in the query parameters.");
        }
        const keys = Object.keys(this.query);
        if (keys.length > 1) {
            throw new CustomError_1.CustomError("Unexpected fields for query", 400, "UNEXPECTED_FIELDS_IN_QUERY", "Details: Only 'id' should be present in the query parameters for this request.");
        }
        return true;
    }
}
exports.QueryIdChecker = QueryIdChecker;
class QueryNameChecker extends checkerInterface_1.Checker {
    constructor(query) {
        super();
        this.query = query;
    }
    check() {
        if (!this.query.hasOwnProperty("name") ||
            typeof String(this.query.name) !== "string") {
            throw new CustomError_1.CustomError("Invalid or missing Name", 400, "INVALID_OR_MISSING_NAME", "Details: The 'Name' must be a valid number and present in the query parameters.");
        }
        const keys = Object.keys(this.query);
        if (keys.length > 1) {
            throw new CustomError_1.CustomError("Unexpected fields for query", 400, "UNEXPECTED_FIELDS_IN_QUERY", "Details: Only 'Name' should be present in the query parameters for this request.");
        }
        return true;
    }
}
exports.QueryNameChecker = QueryNameChecker;
const zod_1 = require("zod");
exports.queryIdSchema = zod_1.z
    .object({
    id: zod_1.z
        .number()
        .int()
        .nonnegative({ message: "id must be a non-negative integer." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid ID", 400, "INVALID_OR_MISSING_ID", err.error.message);
    }),
})
    .strict()
    .catch((err) => {
    throw new CustomError_1.CustomError("Unexpected fields for query", 400, "UNEXPECTED_FIELDS_IN_QUERY", "Details: Only 'id' should be present in the query parameters.");
});
exports.queryNameSchema = zod_1.z
    .object({
    name: zod_1.z
        .string()
        .min(1, { message: "name must be a non-empty string." })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid Name", 400, "INVALID_OR_MISSING_NAME", err.error.message);
    }),
})
    .strict()
    .catch((err) => {
    throw new CustomError_1.CustomError("Unexpected fields for query", 400, "UNEXPECTED_FIELDS_IN_QUERY", err.error.message);
});
