"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateShoppingCartSchema = exports.UpdateShoppingCartChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
class UpdateShoppingCartChecker extends checkerInterface_1.Checker {
    constructor(body) {
        super();
        this.body = body;
    }
    check() {
        if (!this.body.hasOwnProperty("id") ||
            typeof this.body.id !== "number" ||
            isNaN(this.body.id)) {
            throw new CustomError_1.CustomError("Ungültige oder fehlende ID", 400, "INVALID_OR_MISSING_ID", "Details: Die 'id' muss eine gültige Zahl sein und im Anfragekörper vorhanden sein.");
        }
        const hasValidFields = this.body.name !== undefined || this.body.beschreibung !== undefined;
        if (!hasValidFields) {
            throw new CustomError_1.CustomError("Unvollständige Update-Daten", 400, "MISSING_UPDATE_FIELDS", "Details: Mindestens eines der Felder 'name' oder 'beschreibung' ist erforderlich für ein Update.");
        }
        if (this.body.name !== undefined && typeof this.body.name !== "string") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "name"', 400, "INVALID_NAME_TYPE", 'Details: Der Wert für "name" muss ein String sein.');
        }
        if (this.body.beschreibung !== undefined &&
            typeof this.body.beschreibung !== "string") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "beschreibung"', 400, "INVALID_BESCHREIBUNG_TYPE", 'Details: Der Wert für "beschreibung" muss ein String sein.');
        }
        return true;
    }
}
exports.UpdateShoppingCartChecker = UpdateShoppingCartChecker;
const zod_1 = require("zod");
exports.updateShoppingCartSchema = zod_1.z.object({
    id: zod_1.z
        .number()
        .min(1, {
        message: "The 'id' field must be a valid number and greater than 0.",
    })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid or missing 'id'", 400, "INVALID_OR_MISSING_ID", err.error.message);
    }),
    name: zod_1.z
        .string()
        .optional()
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid value for 'name'", 400, "INVALID_NAME_TYPE", err.error.message);
    }),
    beschreibung: zod_1.z
        .string()
        .optional()
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid value for 'beschreibung'", 400, "INVALID_BESCHREIBUNG_TYPE", err.error.message);
    }),
});
