"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addShoppingCartSchema = exports.addShoppingCartChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
class addShoppingCartChecker extends checkerInterface_1.Checker {
    constructor(body) {
        super();
        this.body = body;
    }
    check() {
        if (typeof this.body !== "object" || this.body === null) {
            throw new CustomError_1.CustomError("Ungültiger Body", 400, "INVALID_BODY", "Details: Der Body muss ein gültiges Objekt sein.");
        }
        if (!this.body.hasOwnProperty("name")) {
            throw new CustomError_1.CustomError('Fehlendes Feld "name"', 400, "MISSING_NAME", 'Details: Das Feld "name" ist erforderlich.');
        }
        if (!this.body.hasOwnProperty("beschreibung")) {
            throw new CustomError_1.CustomError('Fehlendes Feld "beschreibung"', 400, "MISSING_BESCHREIBUNG", 'Details: Das Feld "beschreibung" ist erforderlich.');
        }
        if (typeof this.body.name !== "string") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "name"', 400, "INVALID_NAME", 'Details: Der Wert für "name" muss ein String sein.');
        }
        if (typeof this.body.beschreibung !== "string") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "beschreibung"', 400, "INVALID_BESCHREIBUNG", 'Details: Der Wert für "beschreibung" muss ein String sein.');
        }
        return true;
    }
}
exports.addShoppingCartChecker = addShoppingCartChecker;
const zod_1 = require("zod");
exports.addShoppingCartSchema = zod_1.z.object({
    name: zod_1.z
        .string()
        .min(1, {
        message: 'The "name" field is required and must be a non-empty string.',
    })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid 'name' field", 400, "INVALID_NAME", err.error.message);
    }),
    beschreibung: zod_1.z
        .string()
        .min(1, {
        message: 'The "beschreibung" field is required and must be a non-empty string.',
    })
        .catch((err) => {
        throw new CustomError_1.CustomError("Invalid 'beschreibung' field", 400, "INVALID_BESCHREIBUNG", err.error.message);
    }),
});
