"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getShoppingCartByCriteriaChecker = void 0;
const CustomError_1 = require("../../../error/CustomError");
const checkerInterface_1 = require("../../checkerInterface");
class getShoppingCartByCriteriaChecker extends checkerInterface_1.Checker {
    constructor(body) {
        super();
        this.body = body;
        this.possibleCriteria = ["id", "name", "beschreibung"];
    }
    check() {
        let bodyKey = Object.keys(this.body);
        const key = bodyKey[0];
        const value = this.body[key];
        if (bodyKey.length > 1 || bodyKey.length === 0) {
            throw new CustomError_1.CustomError('Ungültige Anzahl von Keys', 400, "INVALID_KEYS", "Details: Es darf genau ein Key vorhanden sein.");
        }
        if (!this.possibleCriteria.includes(key)) {
            throw new CustomError_1.CustomError('Ungültiges Kriterium', 400, "INVALID_CRITERION", `Details: Der Key "${key}" ist kein gültiges Kriterium.`);
        }
        if (key === "id" && (typeof Number(value) !== "number" || isNaN(value))) {
            throw new CustomError_1.CustomError('Ungültiger Wert für "id"', 400, "INVALID_ID", 'Details: Der Wert für "id" muss eine gültige Zahl sein.');
        }
        if (key === "name" && typeof value !== "string") {
            throw new CustomError_1.CustomError('Ungültiger Wert für "name"', 400, "INVALID_NAME", 'Details: Der Wert für "name" muss ein String sein.');
        }
        return true;
    }
}
exports.getShoppingCartByCriteriaChecker = getShoppingCartByCriteriaChecker;
