"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const supertest_1 = __importDefault(require("supertest"));
const baseUrl = "http://localhost:8000";
(0, globals_1.describe)("Order Manager", () => {
    let cartId;
    let itemId;
    (0, globals_1.beforeAll)(() => __awaiter(void 0, void 0, void 0, function* () {
        const cartPayload = {
            name: "Test Cart",
            preis: 10,
            beschreibung: "A test shopping cart",
        };
        const cartRes = yield (0, supertest_1.default)(baseUrl)
            .post("/api/shoppingCart/createShoppingCart")
            .send(cartPayload)
            .set("Content-Type", "application/json")
            .set("Accept", "application/json");
        cartId = cartRes.body.id;
        const itemPayload = {
            name: "Test Item",
            preis: 5,
            beschreibung: "A test item for the shopping cart",
            categoryId: 1
        };
        const itemRes = yield (0, supertest_1.default)(baseUrl)
            .post("/api/article/addArticle")
            .send(itemPayload)
            .set("Content-Type", "application/json")
            .set("Accept", "application/json");
        itemId = itemRes.body.id;
    }));
    (0, globals_1.describe)("Add New Item to Order", () => {
        (0, globals_1.it)("should add a new item to the order and return status 201", () => __awaiter(void 0, void 0, void 0, function* () {
            const payload = {
                cartId: cartId,
                itemId: itemId,
                quantity: 3
            };
            const res = yield (0, supertest_1.default)(baseUrl)
                .post("/api/order/addNewItemToOrder")
                .send(payload)
                .set("Content-Type", "application/json")
                .set("Accept", "application/json");
            const returnedStatus = res.status;
            const expectedStatus = 200;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
        }));
    });
    (0, globals_1.describe)("Get Items in Cart", () => {
        (0, globals_1.it)("should retrieve all items in the cart and return status 200", () => __awaiter(void 0, void 0, void 0, function* () {
            const res = yield (0, supertest_1.default)(baseUrl)
                .get(`/api/order/getItemsInCart?cartId=${cartId}`)
                .set("Content-Type", "application/json");
            const returnedStatus = res.status;
            const expectedStatus = 200;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
            (0, globals_1.expect)(Array.isArray(res.body.items)).toBeTruthy();
            (0, globals_1.expect)(res.body.items.length).toEqual(1);
        }));
    });
    (0, globals_1.describe)("Update Product Quantity", () => {
        (0, globals_1.it)("should update the quantity of an item in the cart and return status 204", () => __awaiter(void 0, void 0, void 0, function* () {
            const payload = {
                cartId: cartId,
                articleId: itemId,
                newQuantity: 5
            };
            const res = yield (0, supertest_1.default)(baseUrl)
                .put("/api/order/updateProductQuantity")
                .send(payload)
                .set("Content-Type", "application/json");
            const returnedStatus = res.status;
            const expectedStatus = 200;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
        }));
    });
    (0, globals_1.describe)("Delete Item from Shopping Cart", () => {
        (0, globals_1.it)("should delete an item from the shopping cart and return status 204", () => __awaiter(void 0, void 0, void 0, function* () {
            const payload = {
                itemId: itemId,
                cartId: cartId
            };
            const res = yield (0, supertest_1.default)(baseUrl)
                .delete(`/api/order/deleteItemFromShoppingCart`)
                .send(payload)
                .set("Content-Type", "application/json");
            const returnedStatus = res.status;
            const expectedStatus = 200;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
        }));
    });
    (0, globals_1.afterAll)(() => __awaiter(void 0, void 0, void 0, function* () {
        let resItem = yield (0, supertest_1.default)(baseUrl).delete(`/api/article/deleteArticle?id=${itemId}`);
        const resCart = yield (0, supertest_1.default)(baseUrl)
            .delete(`/api/shoppingCart/deleteShoppingCart?id=${cartId}`)
            .set("Content-Type", "application/json");
    }));
});
