"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const globals_1 = require("@jest/globals");
const supertest_1 = __importDefault(require("supertest"));
const baseUrl = "http://localhost:8000";
(0, globals_1.describe)("Shopping Cart", () => {
    let cartName = "Mock name";
    let cartId;
    (0, globals_1.describe)("Create Shopping Cart", () => {
        (0, globals_1.it)("should create a new shopping cart and return status 201", () => __awaiter(void 0, void 0, void 0, function* () {
            const payload = {
                name: "Mock name",
                preis: 5,
                beschreibung: "Mock description"
            };
            const res = yield (0, supertest_1.default)(baseUrl)
                .post("/api/shoppingCart/createShoppingCart")
                .send(payload)
                .set("Content-Type", "application/json")
                .set('Accept', 'application/json');
            const returnedStatus = res.status;
            const expectedStatus = 201;
            cartId = res.body.id;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
            (0, globals_1.expect)(res.body).toHaveProperty("id");
        }));
    });
    (0, globals_1.describe)("Get All Shopping Carts", () => {
        (0, globals_1.it)("should retrieve all shopping carts and return status 200", () => __awaiter(void 0, void 0, void 0, function* () {
            const res = yield (0, supertest_1.default)(baseUrl)
                .get("/api/shoppingCart/getAllShoppingCart");
            const returnedStatus = res.status;
            const expectedStatus = 200;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
            (0, globals_1.expect)(Array.isArray(res.body)).toBeTruthy();
        }));
    });
    (0, globals_1.describe)("Get Shopping Cart By Criteria", () => {
        (0, globals_1.it)("should retrieve a shopping cart by criteria and return status 200", () => __awaiter(void 0, void 0, void 0, function* () {
            const res = yield (0, supertest_1.default)(baseUrl)
                .get(`/api/shoppingCart/getShoppingCartByCriteria?name=${cartName}`)
                .set("Content-Type", "application/json");
            const returnedStatus = res.status;
            const expectedStatus = 200;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
            (0, globals_1.expect)(res.body[0]).toHaveProperty("id");
        }));
    });
    (0, globals_1.describe)("Update Shopping Cart", () => {
        (0, globals_1.it)("should update the shopping cart and return status 204", () => __awaiter(void 0, void 0, void 0, function* () {
            const payload = {
                "id": cartId,
                "name": "newName",
                "beschreibung": "the New Description Mock"
            };
            const res = yield (0, supertest_1.default)(baseUrl)
                .put("/api/shoppingCart/updateShoppingCart")
                .send(payload)
                .set("Content-Type", "application/json");
            const returnedStatus = res.status;
            const expectedStatus = 204;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
        }));
    });
    (0, globals_1.describe)("Delete Shopping Cart", () => {
        (0, globals_1.it)("should delete the shopping cart and return status 204", () => __awaiter(void 0, void 0, void 0, function* () {
            const res = yield (0, supertest_1.default)(baseUrl)
                .delete(`/api/shoppingCart/deleteShoppingCart?id=${cartId}`)
                .set("Content-Type", "application/json");
            const returnedStatus = res.status;
            const expectedStatus = 204;
            (0, globals_1.expect)(returnedStatus).toEqual(expectedStatus);
        }));
    });
});
