import { addNewArticle } from "../db/article/addNewArticle";
import { articleObj, getAllArticle } from "../db/article/getAllArticle";
import { getArticleByCriteria } from "../db/article/getArticleByCriteria";
import { Response, Request, NextFunction, response } from "express";
import { updateArticle } from "../db/article/updateArticle";
import { deleteArticle } from "../db/article/deleteArticle";
import { CustomError } from "../error/CustomError";

export class articleController {
  public getAllArticle() {
    return async (req: Request, res: Response, next: NextFunction) => {
      let result;
      try {
        result = await getAllArticle();
      } catch (error: any) {
        next(error);
        return;
      }

      res.status(200).json(result);
    };
  }

  public getProductByCriteria() {
    return async (req: Request, res: Response, next: NextFunction) => {
      let value: string | number =
        req.params.selector == "id"
          ? Number(req.params.value)
          : req.params.value;

      let result;
      try {
        result = await getArticleByCriteria(req.params.selector, value);
      } catch (error) {
        next(error);
        return;
      }
      res.json(result);
    };
  }

  public addArticle() {
    return async (req: Request, res: Response, next: NextFunction) => {
      const { name, preis, beschreibung,categoryId } = req.body;
      let id;

      try {
        id = await addNewArticle(preis, beschreibung, name,categoryId);
      } catch (error) {
        next(error);
        return;
      }

      res.status(201).json({
        message: "article added",
        id: id,
        name: name,
      });
    };
  }

  public updateArticle() {
    return async (req: Request, res: Response, next: NextFunction) => {
      let articleObj: articleObj = req.body;

      let isUpdated;
      try {
        isUpdated = await updateArticle(req.body.id, articleObj);
      } catch (error) {
        next(error);
        return;
      }
      isUpdated
        ? res.status(204).json({ message: "article updated successfully" })
        : res.status(500);
    };
  }

  public deleteArticle() {
    return async (req: Request, res: Response, next: NextFunction) => {
      const id: number = Number(req.query.id);
      try {
        await deleteArticle(id);
      } catch (error) {
        next(error);
        return;
      }

      res.status(204).send();
    };
  }

  public searchProductIngoogle() {
    return async (req: Request, res: Response, next: NextFunction) => {
      const productName = req.query.productName;
      console.log(productName)
      const key = "AIzaSyC4mtQ7jXavedm9KUrBP9n9HVquNobCzrU";
      try {
        const response = await fetch(
          `https://www.googleapis.com/customsearch/v1?key=${key}&cx=a143f4f509e5e4990&q=${productName}`
        );
        if (!response.ok) {
          throw new CustomError(
            await response.json(),
            response.status,
            "UNKNOWN",
            "Data can't be fetched from external api"
          );
        }
        const body = await response.json();
        res.json(body);
      } catch (error) {
        next(
          new CustomError(
            "fetching data Failed ",
            404,
            "UNKNOWN",
            "Data can't be fetched from external api"
          )
        );
      }
    };
  }
}
