import { getAllShoppingCarts } from "../db/shoppingCart/getAllShoppingCarts";
import { createShoppingCart } from "../db/shoppingCart/createShoppingCart";
import { NextFunction, Request, Response } from "express";
import { getShoppingCarteByCriteria } from "../db/shoppingCart/getShoppingCartByCriteria";
import { deleteShoppingCart } from "../db/shoppingCart/deleteShoppingCart";
import { updateShoppingCart } from "../db/shoppingCart/updateShoppingCart";
import {
  getShoppingListContainingItemById,
  getShoppingListContainingItemByName,
} from "../db/shoppingCart/getShoppingListContainingItem";

export class ShoppingCartController {
  public createShoppingCart() {
    return async (req: Request, res: Response, next: NextFunction) => {
      let body = req.body;
      let id;
      try {
        id = await createShoppingCart(body);
      } catch (error) {
        next(error);
        return;
      }
      res.status(201).json({
        message: "shopping cart created ",
        id: id,
      });
    };
  }

  public getAllShoppingCart() {
    return async (req: Request, res: Response, next: NextFunction) => {
      let result;

      try {
        result = await getAllShoppingCarts();
      } catch (error) {
        next(error);
        return;
      }

      res.status(200).json(result);
    };
  }

  public getShoppingCarteByCriteria() {
    return async (req: Request, res: Response, next: NextFunction) => {
      let value: string | number =
        req.params.selector == "id"
          ? Number(req.params.value)
          : req.params.value;
      let result;
      try {
        result = await getShoppingCarteByCriteria(req.params.selector, value);
      } catch (error) {
        next(error);
        return;
      }
      res.json(result);
    };
  }

  public getShoppingListContainingItemById() {
    return async (req: Request, res: Response, next: NextFunction) => {
      const id = req.query.id;
      console.log(id);
      try {
        const response = await getShoppingListContainingItemById(Number(id));
        res.json(response);
      } catch (error) {
        next(error);
      }
    };
  }

  public getShoppingListContainingItemByName() {
    return async (req: Request, res: Response, next: NextFunction) => {
      const name = req.query.name;
      try {
        const response = await getShoppingListContainingItemByName(
          String(name)
        );
        res.json(response);
      } catch (error) {
        next(error);
      }
    };
  }

  public deleteShoppingCart() {
    return async (req: Request, res: Response, next: NextFunction) => {
      const id: number = Number(req.query.id);

      try {
        await deleteShoppingCart(id);
      } catch (error) {
        next(error);
        return;
      }
      res.status(204).send();
    };
  }

  public updateShoppingCart() {
    return async (req: Request, res: Response, next: NextFunction) => {
      const { id, name, beschreibung } = req.body;
      const body: { name: string; beschreibung: string } = {
        name: name,
        beschreibung: beschreibung,
      };

      try {
        await updateShoppingCart(id, body);
      } catch (error) {
        next(error);
        return;
      }
      res.status(204).json({ message: "Shopping cart updated successfully" });
    };
  }
}
