import { DB } from "../connect";
import { CustomError } from "../../error/CustomError";

export const getItemsInOrder = async (cartId: number) => {
  let db = DB.getDB( );
  let client = db.Client;

  let cartInfoQuery = `
    SELECT name AS cartName, beschreibung AS cartBeschreibung, erstellungsdatum AS erstellungsDatum
    FROM einkaufliste
    WHERE id = $1
  `;

  let cartInfo = await client
    .query(cartInfoQuery, [cartId])
    .then((res) => {
      if (res.rowCount === 0) {
        throw new CustomError(
          "The cart ID does not exist",
          404,
          "ID_NOT_EXISTING",
          "No existing cart ID"
        );
      }
      return res.rows[0]; 
    })
    .catch((err) => {
      throw err;
    });


  let query = `
    SELECT a.id AS articleId , m.menge AS quantity, a.name AS articleName, a.preis AS articlePreis, a.beschreibung AS articleBeschreibung
    FROM mengeRealtation m
    JOIN article a ON a.id = m.articleId
    WHERE m.einkauflisteId = $1
  `;

  type ArticleInfo = {
    articleid: number ;
    quantity: number;
    articlename: string;
    articlepreis: number;
    articlebeschreibung: string;
  };

  let values = [cartId];
  let articles: ArticleInfo[] = [];

  await client
    .query(query, values)
    .then((res) => {
      articles = res.rows;
    })
    .catch((err) => {
      throw err;
    })

  let response = {
    cartId: cartId,
    name: cartInfo.cartname,
    beschreibung: cartInfo.cartbeschreibung,
    erstellungsdatum: cartInfo.erstellungsdatum, 
    items: articles.map((item) => ({
      id : item.articleid , 
      name: item.articlename,
      preis: Number(item.articlepreis),
      beshreibung: item.articlebeschreibung,
      quantity: item.quantity,
    })),
  };

  return response;
};