import { CustomError } from "../../error/CustomError";
import { DB } from "../connect";
import { shoppingCart } from "./getAllShoppingCarts";

export const getShoppingCarteByCriteria = async (
  criteria: string,
  querySelector: string | number
): Promise<shoppingCart[]> => {
  const query = `
        select * 
        from einkaufliste 
        where ${criteria} like $1
        `;

  let values = [`%${querySelector}%`];
  let result: shoppingCart[] = [];

  let db = DB.getDB( );
  let client = db.Client;

  await client
    .query(query, values)
    .then((res) => {
      result = res.rows;

      if (result.length === 0) {
        throw new CustomError(
          "No Items Found in Cart",
          404,
          "CART_EMPTY",
          `No items were found in the shopping cart matching the criteria '${criteria}' with value '${querySelector}'.`
        );
      }

    })
    .catch((err) => {
        throw err ; 
    })

  return result;
};
