import { Request, Response, NextFunction } from "express";
import { ValidityChecker } from "./validityCheck/ValidityCheker";
import { extractTargetSource } from "./validityCheck/utils/extractTargetSource";
import { ProductValidityChecker } from "./validityCheck/productCheck/ProductValidityChecker";
import { ShoppingCartValidityChecker } from "./validityCheck/shoppingCartCheck/ShoppingcartValidiyChecker";
import { OrderValidityChecker } from "./validityCheck/orderCheck/OrderValidityChecker";
import { CategoryValidityChecker } from "./validityCheck/categoryCheck/CategoryValidityChecker";

export const check = (req: Request, res: Response, next: NextFunction) => {
  let path = req.path;
  const fullUrl = req.protocol + "://" + req.get("host") + req.originalUrl;

  const targetSource = extractTargetSource(fullUrl);
  let checker: ValidityChecker;

  if (targetSource == "article") {
    checker = new ProductValidityChecker(path, req);
  } else if (targetSource == "shoppingCart") {
    checker = new ShoppingCartValidityChecker(path, req);
  } else if (targetSource == "category") {
    checker = new CategoryValidityChecker(path, req);
  } else if (targetSource == "order") {
    checker = new OrderValidityChecker(path, req);
  }

  try {
    checker!.validateUsingUrl();
    next();
  } catch (error) {
    next(error);
    return;
  }
};
