import { CustomError } from "../../../error/CustomError";
import { z } from "zod";
export const categoryParamsIdSchema = z
  .object({
    categoryId: z
      .string()
      .refine(
        (data) => {
          const regex = /[0-9]+/;
          return regex.test(data) && Number(data) >= 0;
        },
        { message: "categoryId must be a positive integer." }
      )
      .catch((err) => {
        throw new CustomError(
          "Invalid categoryId",
          422,
          "INVALID_CATEGORY_ID",
          err.error.message
        );
      }),
  })
  .strict()
  .catch((err) => {
    const keys = Object.keys(err.input || {});
    throw new CustomError(
      "Unexpected fields in params",
      422,
      "UNEXPECTED_FIELDS",
      err.error.message
    );
  });
