import { CustomError } from "../../../error/CustomError";
import { z } from "zod";

export const addItemSchema = z.object({
  itemId: z
    .number()
    .int()
    .nonnegative({ message: "itemId must be a non-negative integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid itemId",
        400,
        "INVALID_ITEM_ID",
        err.error.message
      );
    }),
  cartId: z
    .number()
    .int()
    .nonnegative({ message: "cartId must be a non-negative integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid cartId",
        400,
        "INVALID_CART_ID",
        err.error.message
      );
    }),
  quantity: z
    .number()
    .int()
    .positive({ message: "quantity must be a positive integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid quantity",
        400,
        "INVALID_QUANTITY",
        err.error.message
      );
    }),
});

export const getItemsSchema = z.object({
  cartId: z
    .string()
    .refine((data) => /[0-9]+/.test(data) && Number(data) >= 0, {
      message: "cartId must be a non-negative integer.",
    })
    .catch((err) => {
      throw new CustomError(
        "Invalid cartId",
        400,
        "INVALID_CART_ID",
        err.error.message
      );
    }),
});

export const updateProductQuantitySchema = z.object({
  cartId: z
    .number()
    .int()
    .nonnegative({ message: "cartId must be a non-negative integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid cartId",
        400,
        "INVALID_CART_ID",
        err.error.message
      );
    }),
  articleId: z
    .number()
    .int()
    .nonnegative({ message: "articleId must be a non-negative integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid articleId",
        400,
        "INVALID_ARTICLE_ID",
        err.error.message
      );
    }),
  newQuantity: z
    .number()
    .int()
    .positive({ message: "newQuantity must be a positive integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid newQuantity",
        400,
        "INVALID_QUANTITY",
        err.error.message
      );
    }),
});

export const deleteItemSchema = z.object({
  itemId: z
    .number()
    .int()
    .nonnegative({ message: "itemId must be a non-negative integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid itemId",
        400,
        "INVALID_ITEM_ID",
        err.error.message
      );
    }),
  cartId: z
    .number()
    .int()
    .nonnegative({ message: "cartId must be a non-negative integer." })
    .catch((err) => {
      throw new CustomError(
        "Invalid cartId",
        400,
        "INVALID_CART_ID",
        err.error.message
      );
    }),
});
