import { CustomError } from "../../../error/CustomError";
import { z } from "zod";

export const addProductSchema = z.object({
  preis: z
    .number()
    .min(0, { message: "Price must be greater than or equal to 0." })
    .catch((err) => {
      throw new CustomError(
        "Invalid price",
        422,
        "PRICE_ERROR",
        err.error.message
      );
    }),

  beschreibung: z
    .string()
    .min(1, { message: "Description must be a non-empty string." })
    .catch((err) => {
      throw new CustomError(
        "Invalid description",
        422,
        "DESCRIPTION_ERROR",
        err.error.message
      );
    }),

  name: z
    .string()
    .min(1, { message: "Name must be a non-empty string." })
    .catch((err) => {
      throw new CustomError(
        "Invalid name",
        422,
        "NAME_ERROR",
        err.error.message
      );
    }),

  id: z.number().optional(),

  categoryId: z
    .number()
    .min(1, { message: "CategoryId must be greater than 0." })
    .optional()
    .catch((err) => {
      throw new CustomError(
        "Invalid categoryId",
        422,
        "CATEGORY_ERROR",
        err.error.message
      );
    }),
});

export const deleteArticleSchema = z.object({
  id: z
    .string()
    .regex(/^\d+$/, { message: "The 'id' parameter must be a valid number." })
    .transform((val) => Number(val))
    .refine((val) => !isNaN(val), {
      message: "The 'id' parameter must be a number.",
    })
    .catch((err) => {
      throw new CustomError(
        "Invalid 'id' Parameter",
        400,
        "INVALID_ID",
        err.error.message
      );
    }),
});

export const updateProductSchema = z.object({
  preis: z
    .number()
    .min(0, { message: "Price must be greater than or equal to 0." })
    .catch((err) => {
      throw new CustomError(
        "Invalid price",
        422,
        "PRICE_ERROR",
        err.error.message
      );
    }),

  beschreibung: z
    .string()
    .min(1, { message: "Description must be a non-empty string." })
    .catch((err) => {
      throw new CustomError(
        "Invalid description",
        422,
        "DESCRIPTION_ERROR",
        err.error.message
      );
    }),

  name: z
    .string()
    .min(1, { message: "Name must be a non-empty string." })
    .catch((err) => {
      throw new CustomError(
        "Invalid name",
        422,
        "NAME_ERROR",
        err.error.message
      );
    }),

  id: z
    .number()
    .min(1, { message: "ID must be greater than 0." })
    .catch((err) => {
      throw new CustomError("Invalid id", 422, "ID_ERROR", err.error.message);
    }),
});
