import { ValidityChecker } from "../ValidityCheker";
import { Request } from "express";
import { queryParamsSchema } from "../utils/queryParamsSchema";
import {
  addProductSchema,
  deleteArticleSchema,
  updateProductSchema,
} from "./Product.schemas";

export class ProductValidityChecker extends ValidityChecker {
  path: string;
  req: Request;
  constructor(path: string, req: Request) {
    super();
    this.path = path;
    this.req = req;
  }
  validateUsingUrl(): boolean {
    if (this.path == "/addArticle") {
      this.setSchema(addProductSchema);
      this.setObject(this.req.body);
      return this.validate();
    }
    if (this.path == "/getProductByCriteria") {
      let body = { ...this.req.query };
      this.setSchema(queryParamsSchema);
      this.setObject(body);

      const isValid = this.validate();
      if (isValid) {
        let criteria = Object.keys(body)[0];
        this.req.params.selector = criteria;
        this.req.params.value = String(body[criteria]);
      }
      return isValid;
    }

    if (this.path === "/updateArticle") {
      this.setSchema(updateProductSchema);
      this.setObject(this.req.body);
      return this.validate();
    }

    if (this.path === "/deleteArticle") {
      this.setSchema(deleteArticleSchema);
      this.setObject(this.req.query);
      return this.validate();
    }

    return true;
  }
}
