import { Router } from "express";
import { ShoppingCartController } from "../controller/shoppingCartController";
import { check } from "../middleware/check";
import { IRouter } from "./RouterInterface";

export class ShoppingCartRouter implements IRouter {
  public router: Router;
  private controller: ShoppingCartController;
  public routerSubPath: string = "/shoppingCart";

  constructor() {
    this.router = Router();
    this.controller = new ShoppingCartController();
    this.registerRoutes();
  }

  public registerRoutes(): void {
    this.router.post("/createShoppingCart", check, this.controller.createShoppingCart());

    this.router.get("/getAllShoppingCart", this.controller.getAllShoppingCart());

    this.router.get("/getShoppingCartByCriteria", check, this.controller.getShoppingCarteByCriteria());

    this.router.get("/getShoppingListContainingItemById", check, this.controller.getShoppingListContainingItemById());

    this.router.get("/getShoppingListContainingItemByName", check, this.controller.getShoppingListContainingItemByName());

    this.router.put("/updateShoppingCart", check, this.controller.updateShoppingCart());

    this.router.delete("/deleteShoppingCart", check, this.controller.deleteShoppingCart());
  }
}
