import express, { Express, Router } from "express";
import helmet from 'helmet';
import { RouterAssembler } from "../routes/RoutesAssember";
import { allowCors } from "../middleware/CORS/allowCors";
import { ArticleRouter } from "../routes/articleRouter";
import { OrderRouter } from "../routes/orderRoutes";
import { CategoryRouter } from "../routes/categoryRouter";
import { IRouter } from "../routes/RouterInterface";
import { errorMiddleWare } from "../middleware/Error/errorMiddleware";
import { ShoppingCartRouter } from "../routes/shoppingCartRouter";


export class Server {
  routes: IRouter[] = [new ArticleRouter(), new OrderRouter(), new ShoppingCartRouter(), new CategoryRouter()];
  rooRouter?: Router;
  app: Express;
  port: number; 

  constructor() {
    this.app = express();
    this.port = 8000;
  }

  private registerMiddleware(): void {
    this.rooRouter!.use(errorMiddleWare);
    this.app.use (helmet())
    this.app.use(express.json());
    this.app.use(allowCors);
    this.app.use("/api", this.rooRouter!);
  }

  private registerRootRouter(): void {
    const routerAssembler = new RouterAssembler(this.routes);
    routerAssembler.assembleRoutes();
    this.rooRouter = routerAssembler.assembledRouter;
  }

  public listen(): void {
    this.app.listen(this.port, () => {
      console.log(`app listening on port ${this.port}`);
    });
  }

  public start(): void {
    this.registerRootRouter();
    this.registerMiddleware();
    this.listen();
  }
}
