import { describe, expect, it, jest, test } from '@jest/globals';
import supertest, { Response } from 'supertest';

const baseUrl = "http://localhost:8000";

describe("product", () => {

    let id: number;
    describe("add Product", () => {
        it("should send back status 201", async () => {
            const payload = {
                "preis": 2,
                "beschreibung": " the best beschriebung ",
                "name": "usefull name",
                "categoryId":1
            }

            const res: Response = await supertest(baseUrl)
                .post("/api/article/addArticle")
                .send(payload)
                .set("Content-Type", "application/json")
                .set('Accept', 'application/json')

            const returnedStatus = res.status;
            id = res.body.id;
            const expectedStatus = 201;

            expect(expectedStatus).toEqual(returnedStatus);
        })
    })

    describe(baseUrl, () => {
        it("should send back more than one article ", async () => {
            let res = await supertest(baseUrl).get("/api/article/getAllProducts")
            expect(res.status).toEqual(200);
            const returnedLength = res.body.length;
            const EXPECTED_VALUE = 1;

            expect(returnedLength).toBeGreaterThanOrEqual(EXPECTED_VALUE);
        })
    })

    describe(baseUrl, () => {
        it(` should update the article with the id ${id} `, async () => {
            let res = await supertest(baseUrl).put("/api/article/updateArticle").send({
                id: id,
                name: "other name ",
                preis: 5,
                beschreibung: "other Description"
            })

            const EXPECTED_STATUS = 204;
            const returnedStatus = res.status;
            expect(EXPECTED_STATUS).toEqual(returnedStatus);
        })
    })

    describe(baseUrl, () => {
        it("should delete the added article", async () => {
            let res = await supertest(baseUrl).delete(`/api/article/deleteArticle?id=${id}`);
            let returnedStatus = res.status;
            let ExpectedStatus = 204;
            expect(ExpectedStatus).toEqual(returnedStatus);
        })
    })
})