import { describe, expect, it, jest, test } from '@jest/globals';
import supertest, { Response } from 'supertest';

const baseUrl = "http://localhost:8000";

describe("Shopping Cart", () => {

    let cartName: String = "Mock name";
    let cartId :number ; 

    describe("Create Shopping Cart", () => {
        it("should create a new shopping cart and return status 201", async () => {
            const payload = {
                name: "Mock name",
                preis: 5,
                beschreibung: "Mock description"
            };

            const res: Response = await supertest(baseUrl)
                .post("/api/shoppingCart/createShoppingCart")
                .send(payload)
                .set("Content-Type", "application/json")
                .set('Accept', 'application/json');

            const returnedStatus = res.status;
            const expectedStatus = 201;
            cartId = res.body.id ; 

            expect(returnedStatus).toEqual(expectedStatus);
            expect(res.body).toHaveProperty("id");
        });
    });

    describe("Get All Shopping Carts", () => {
        it("should retrieve all shopping carts and return status 200", async () => {
            const res: Response = await supertest(baseUrl)
                .get("/api/shoppingCart/getAllShoppingCart");

            const returnedStatus = res.status;
            const expectedStatus = 200;

            expect(returnedStatus).toEqual(expectedStatus);
            expect(Array.isArray(res.body)).toBeTruthy();
        });
    });

    describe("Get Shopping Cart By Criteria", () => {
        it("should retrieve a shopping cart by criteria and return status 200", async () => {
            const res: Response = await supertest(baseUrl)
                .get(`/api/shoppingCart/getShoppingCartByCriteria?name=${cartName}`)
                .set("Content-Type", "application/json");

            const returnedStatus = res.status;
            const expectedStatus = 200;

            expect(returnedStatus).toEqual(expectedStatus);
            expect(res.body[0]).toHaveProperty("id");
        });
    });

    describe("Update Shopping Cart", () => {
        it("should update the shopping cart and return status 204", async () => {
            const payload = {
                    "id": cartId,
                    "name" : "newName" ,
                    "beschreibung": "the New Description Mock"
            };

            const res: Response = await supertest(baseUrl)
                .put("/api/shoppingCart/updateShoppingCart")
                .send(payload)
                .set("Content-Type", "application/json");

            const returnedStatus = res.status;
            const expectedStatus = 204;

            expect(returnedStatus).toEqual(expectedStatus);
        });
    });

    describe("Delete Shopping Cart", () => {
        it("should delete the shopping cart and return status 204", async () => {
            const res: Response = await supertest(baseUrl)
                .delete(`/api/shoppingCart/deleteShoppingCart?id=${cartId}`)
                .set("Content-Type", "application/json");

            const returnedStatus = res.status;
            const expectedStatus = 204;

            expect(returnedStatus).toEqual(expectedStatus);
        });
    });
});
